"""add_capture_hostname_to_projects_0013

Revision ID: 82b950a0c033
Revises: 0012
Create Date: 2026-03-05 21:58:35.574374
"""
from typing import Sequence, Union

from alembic import op
import sqlalchemy as sa

# revision identifiers, used by Alembic.
revision: str = '82b950a0c033'
down_revision: Union[str, None] = '0012'
branch_labels: Union[str, Sequence[str], None] = None
depends_on: Union[str, Sequence[str], None] = None


def upgrade() -> None:
    op.execute(sa.text(
        "ALTER TABLE projects ADD COLUMN IF NOT EXISTS capture_hostname TEXT NOT NULL DEFAULT ''"
    ))


def downgrade() -> None:
    op.execute(sa.text(
        "ALTER TABLE projects DROP COLUMN IF EXISTS capture_hostname"
    ))
