"""API client methods for task attachments."""

from __future__ import annotations

from peon_mcp.common.base_client import BaseAPIClient


class AttachmentClient(BaseAPIClient):
    """Attachment API client methods."""

    async def list_task_attachments(self, task_id: int) -> list[dict] | str:
        return await self._request("GET", f"/api/tasks/{task_id}/attachments")

    async def delete_attachment(self, attachment_id: int) -> dict | str:
        return await self._request("DELETE", f"/api/attachments/{attachment_id}")
