"""GitHub inbound webhook receiver."""

# Import handler modules so their @register_handler decorators run at startup.
from peon_mcp.github_webhooks import auto_merge as _auto_merge  # noqa: F401
from peon_mcp.github_webhooks import ci_failure_handler as _ci_failure_handler  # noqa: F401
from peon_mcp.github_webhooks import merge_conflict_handler as _merge_conflict_handler  # noqa: F401
from peon_mcp.github_webhooks import pr_merged as _pr_merged  # noqa: F401
from peon_mcp.github_webhooks import pr_review_handler as _pr_review_handler  # noqa: F401
from peon_mcp.github_webhooks import pr_reviewer as _pr_reviewer  # noqa: F401
from peon_mcp.github_webhooks import pr_risk as _pr_risk  # noqa: F401
from peon_mcp.github_webhooks import subscribers as _subscribers  # noqa: F401
